## Lana

```console
    .-.'  `; `-._  __  _
   (_,         .-:'  `; `-._
 ,'o"(        (_,           )
(__,-'      ,'o"(            )>
   (       (__,-'            )
    `-'._.--._(             )
       |||  |||`-'._.--._.-'
                  |||  |||
```

**L***inear* **a***lgebra* *for* **n***octurnal and* **a***dventurous data scientists.*

## Install 

```console
pip install lana
```

## Example 

```python
from lana import Matrix

mat = Matrix.zeros((3,3))
mat.print()
print(mat.shape)
```

